"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteDraftOrdersWorkflow = exports.deleteDraftOrderWorkflowId = void 0;
const workflows_sdk_1 = require("@medusajs/framework/workflows-sdk");
const utils_1 = require("@medusajs/framework/utils");
const common_1 = require("../../common");
const steps_1 = require("../steps");
const validateDraftOrdersStep = (0, workflows_sdk_1.createStep)("validate-draft-orders", async (data) => {
    if (data.orders.some((order) => order.status !== "draft" || !order.is_draft_order)) {
        throw new Error("One or more orders are not draft");
    }
    if (data.orders.some((order) => order.deleted_at)) {
        throw new Error("One or more orders are already deleted");
    }
});
exports.deleteDraftOrderWorkflowId = "delete-draft-order";
/**
 * This workflow deletes draft orders.
 *
 * You can also use this workflow within your customizations or your own custom workflows, allowing you to wrap custom logic around canceling an order.
 *
 * @example
 * const { result } = await deleteDraftOrderWorkflow(container)
 * .run({
 *   input: {
 *     order_ids: ["order_123", "order_456"],
 *   }
 * })
 *
 * @summary
 *
 * Delete draft orders.
 *
 * @property hooks.orderCanceled - This hook is executed after the order is canceled. You can consume this hook to perform custom actions on the canceled order.
 */
exports.deleteDraftOrdersWorkflow = (0, workflows_sdk_1.createWorkflow)(exports.deleteDraftOrderWorkflowId, (input) => {
    const orderQuery = (0, common_1.useQueryGraphStep)({
        entity: "orders",
        fields: ["id", "status", "is_draft_order", "deleted_at"],
        filters: { id: input.order_ids },
        options: { throwIfKeyNotFound: true },
    }).config({ name: "get-draft-order" });
    const orders = (0, workflows_sdk_1.transform)({ orderQuery }, ({ orderQuery }) => {
        return orderQuery.data;
    });
    validateDraftOrdersStep({ orders });
    (0, common_1.removeRemoteLinkStep)({
        [utils_1.Modules.ORDER]: { order_id: input.order_ids },
    });
    (0, steps_1.deleteDraftOrdersStep)({ orderIds: input.order_ids });
    return new workflows_sdk_1.WorkflowResponse(void 0);
});
//# sourceMappingURL=delete-draft-order.js.map